<?php
namespace Teknisa\PLA\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;

class Pla03200Report extends \Zeedhi\Framework\Controller\Report {

    protected $reportService;
    protected $qr2Strategy;
    protected $util;
    protected $environment;
    protected $crudService;
    protected $nrlista;
    protected $birtStrategy;

    public function __construct($reportService, $qr2Strategy, $util, $environment, $crudService, $birtStrategy) {
        $this->reportService = $reportService;
        $this->qr2Strategy = $qr2Strategy;
        $this->util = $util;
        $this->environment = $environment;
        $this->crudService = $crudService;
        $this->birtStrategy = $birtStrategy;
    }

    protected $reportMapping = array (
    "PLA32000" =>
        array (
            "strategy" => "BIRT",
            "parameterMapping" =>
            array (
                "NRLISTA"   => "NRLISTA",
                "DTVIGINI"  => "DTINICIAL",
                "DTVIGFIN"  => "DTFINAL",
                "NRORG"     => "P_NRORG",
                "IDTIPORESTRICAO" => "P_IDTIPORESTRICAO"
            )
        )
    );

    public function createRemoteReport(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->beforeProcessReport($request, $response);
            $reportURL = $this->processReport($request);
            $response->addMessage(new DTO\Response\Message($reportURL));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        } finally {}
    }

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $cdfiliserv = $this->getCdfiliserv($row);
        $this->nrlista = $this->util->insertLista($cdfiliserv);
        $row["NRLISTA"] = $this->nrlista;
        $row["NRORG"] = $this->environment->getNrOrg();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
    }

    public function getCdfiliserv($row) {
        if ($row["NMSERVICO_ALL"] != "T") {
            return $row["CDFILISERV"];
        } else {
            $cdgrupfili = isset($row['CDGRUPFILI']) && $row['CDGRUPFILI'] ? $row['CDGRUPFILI'] : 'T'; 
            $conditions = array(
                array(
                    "columnName" => "CDFILIAL",
                    "operator"   => '=',
                    "value"      => $row["NMFILIAL_ALL"] == "T" ? "T" : implode("_",$row['CDFILIAL'])
                ),
                array(
                    "columnName" => "CDGRUPSERV",
                    "operator"   => '=',
                    "value"      => "T"
                ),
                array(
                    "columnName" => "CDOPERADOR",
                    "operator"   => '=',
                    "value"      => "OPERADOR_LOGADO"
                ),
                array(
                    "columnName" => "CDGRUPFILI",
                    "operator"   => "=",
                    "value"      => $cdgrupfili
                )
            );
            $dataSet = $this->crudService->getFilteredDataSet("servico_operador_filgrupfili_filial_grupserv", $conditions);
            $rows = $dataSet->getRows();
            $cdfiliserv = array();
            foreach ($rows as $row) {
                array_push($cdfiliserv, $row["CHAVE"]);
            }
            return $cdfiliserv;
        }
    }
} 